@@ -4,7 +4,7 @@
 distname = "cubicweb-tag"
 modname = distname.split('-', 1)[1]
 
-numversion = (1, 5, 1)
+numversion = (1, 5, 2)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -13,7 +13,8 @@ http://www.logilab.fr/ -- mailto:contact@logilab.fr'''
 
 author = "Logilab"
 author_email = "contact@logilab.fr"
-web = ''
+web = 'http://www.cubicweb.org/project/%s' % distname
+
 
 short_desc = "Tag support for the CubicWeb framework"
 long_desc = """CubicWeb is a entities / relations bases knowledge management system
@@ -49,3 +50,9 @@ except OSError:
 cube_eid = 20312
 # used packages
 __use__ = ()
+classifiers = [
+           'Environment :: Web Environment',
+           'Framework :: CubicWeb',
+           'Programming Language :: Python',
+           'Programming Language :: JavaScript',
+]
